In TextLCD_I2C_N Class, added void setContrast(unsigned char c) function as temporary. This is for ST7032i non-volume type contrast control.

Dependents:   LPC1114_data_logger RTC_w_COM Frequency_Counter_w_GPS_1PPS CW_Decoder_using_FFT_on_F446 ... more

Fork of TextLCD by Wim Huiskamp

In TextLCD_I2C_N Class, added void setContrast(unsigned char c) function as temporary.

Revision:
29:986538f94abe
Parent:
28:30fa94f7341c
Child:
30:4c57a022a56c
--- a/TextLCD.h	Sat Jun 14 17:04:25 2014 +0000
+++ b/TextLCD.h	Sun Jun 15 03:22:32 2014 +0000
@@ -9,7 +9,8 @@
  *               2013, v07: WH, Added support for backlight and include portdefinitions for LCD2004 Module from DFROBOT
  *               2014, v08: WH, Refactored in Base and Derived Classes to deal with mbed lib change regarding 'NC' defined DigitalOut pins
  *               2014, v09: WH/EO, Added Class for Native SPI controllers such as ST7032 
  *               2014, v10: WH, Added Class for Native I2C controllers such as ST7032i, Added support for MCP23008 I2C portexpander, Added support for Adafruit module  
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -406,7 +407,14 @@
      */
     void setUDC(unsigned char c, char *udc_data);
 
-
+// JH1PJL from here ->
+    /** Set Contrast
+     *
+     * @param unsigned char c   contrast data   
+     */
+    void setContrast(unsigned char c);
+// JH1PJL <- to here
+   
 protected:
 
    /** LCD controller select, mainly used for LCD40x4
@@ -9,7 +9,8 @@
  *               2014, v08: WH, Refactored in Base and Derived Classes to deal with mbed lib change regarding 'NC' defined DigitalOut pins
  *               2014, v09: WH/EO, Added Class for Native SPI controllers such as ST7032 
- *               2014, v10: WH, Added Class for Native I2C controllers such as ST7032i, Added support for MCP23008 I2C portexpander, Added support for Adafruit module  
+ *               2014, v10: WH, Added Class for Native I2C controllers such as ST7032i, Added support for MCP23008 I2C portexpander, Added support for Adafruit module
+ *               2014, v11: SW, added setContrast function for ST7032i only by JH1PJL  
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy